@@ -10,10 +10,12 @@ pub fn verify(proof: Vec<[u8; 32]>, root: [u8; 32], leaf: [u8; 32]) -> bool {
     for proof_element in proof.into_iter() {
         if computed_hash <= proof_element {
             // Hash(current computed hash + current element of the proof)
-            computed_hash = solana_program::keccak::hashv(&[&computed_hash, &proof_element]).0;
+            computed_hash =
+                anchor_lang::solana_program::keccak::hashv(&[&computed_hash, &proof_element]).0;
         } else {
             // Hash(current element of the proof + current computed hash)
-            computed_hash = solana_program::keccak::hashv(&[&proof_element, &computed_hash]).0;
+            computed_hash =
+                anchor_lang::solana_program::keccak::hashv(&[&proof_element, &computed_hash]).0;
         }
     }
     // Check if the computed hash (root) is equal to the provided root
